__version__="2023.3.231211"
__author__ ="Ludwig Corales M. dexsys@gmail.com"
__all__=['ClearCrt','CleanText','Color','logs','ProgressBar','Table',
         '_PRUEBA','_TIPOEJECUCION','PrintError','Cronometro','ImportarHojasXLSX','Box','toVars','GenerateQuery']

#,'','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','','']from .Funciones import leer_pdf

from .libPy2023_l import ClearCrt,CleanText,Color,logs,ProgressBar,Table,\
         _PRUEBA,_TIPOEJECUCION,PrintError,Cronometro,ImportarHojasXLSX,\
         Box,toVars,GenerateQuery